@@ -2,7 +2,7 @@ from typing import Any, List
 
 from flask import Flask
 
-from flask_mico.util import import_class_in_module
+from flask_mico.util import import_attr_in_module
 
 
 def _handle(app: Flask, mid_: Any, point_name: str = None):
@@ -29,5 +29,5 @@ def register_middlewares(app: Flask, middlewares: List[Any]):
         middlewares: List of mid in order
     """
     for mid_path in middlewares:
-        mid_ = import_class_in_module(mid_path)
+        mid_ = import_attr_in_module(mid_path)
         _handle(app, mid_())
